# Prompt Template Files

Janus supports defining custom prompts in text files.

```
directory_name/
    system.txt
    human.txt
    variables.json (optional)
```

## Prompt templates
- `system.txt` contains text representing the system prompt template,
  + Ex. "Your purpose is to understand {SOURCE_LANGUAGE} code."
- `human.txt` contains text representing the human prompt template.
  + Ex. "Summarize the contents of the following {SOURCE_LANGUAGE} code in {written_language} sentences.

Both prompt templates can make use of f-string-style arguments, i.e. `{VARIABLE}`. Multiple lines are supported.

To reuse a prompt, say for the same system directive with differing output styles, create a symbolic link to the original file.  For example:
`ln -s ../document/system.txt system.txt`

## Variables
- (Optional) `variables.json` contains a JSON object representing additional variables and their values used in the templates above, beyond what is provided to Janus via command-line arguments.
  + Ex.
    ```
    {
        "written_language": "Spanish"
    }
    ```
